@@ -1,4 +1,5 @@
 package Marc::Formater::Yaml;
+# ABSTRACT: Marc record formater into YAML representation
 
 use namespace::autoclean;
 use Moose;
@@ -26,19 +27,19 @@ __END__
 
 =head1 NAME
 
-Marc::Formater::Yaml
+Marc::Formater::Yaml - Marc record formater into YAML representation
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 AUTHOR
 
-Frédéric Demians <f.demians@tamil.fr>
+Frederic Demians <f.demians@tamil.fr>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Frédéric Demians.
+This software is copyright (c) 2010 by Frederic Demians.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
